# External Dependencies

This file lists the dependencies used in this repository.

| Dependency                                   | License     |
| -------------------------------------------- | ----------- |
| @types/node - 14.0.26                        | MIT         |
| tweetnacl@1.0.3                              | Unilicense  |
| https://deno.land/std@0.75.0                 | MIT License |
| https://github.com/dr-useless/tweetnacl-deno | Unilicense  |
| Dev Dependencies Fanout (267)                |             |
| ava@3.12.1                                   | MIT         |
| typedoc@0.19.1                               | Apache-2.0  |
| typescript@4.0.2                             | Apache-2.0  |
